@@ -177,6 +177,8 @@ class ClientDialog(QDialog):
         self.setModal(False)
         self.btnHeight = 0
         self.answered = False
+        self.move = None
+        self.sorry = None
 
     def keyPressEvent(self, event):
         """ESC selects default answer"""
@@ -215,8 +217,7 @@ class ClientDialog(QDialog):
                 _, _, tileTxt = button.message.toolTip(button, uiTile.tile)
                 if tileTxt:
                     txt.append(tileTxt)
-            txt = '<br><br>'.join(txt)
-            uiTile.setToolTip(txt)
+            uiTile.setToolTip('<br><br>'.join(txt))
         if self.client.game.activePlayer == self.client.game.myself:
             Internal.scene.handSelectorChanged(
                 self.client.game.myself.handBoard)
@@ -344,8 +345,6 @@ class ClientDialog(QDialog):
         if self.answered:
             # sometimes we get this event twice
             return
-        self.timer.stop()
-        self.answered = True
         if button is None:
             button = self.focusWidget()
         if isinstance(button, Message):
@@ -354,8 +353,14 @@ class ClientDialog(QDialog):
         else:
             answer = button.message
         if not self.client.game.myself.sayable[answer]:
-            Sorry(m18n('You cannot say %1', answer.i18nName))
+            self.proposeAction().setFocus() # go back to default action
+            self.sorry = Sorry(m18n('You cannot say %1', answer.i18nName))
             return
+        self.timer.stop()
+        self.answered = True
+        if self.sorry:
+            self.sorry.cancel()
+        self.sorry = None
         Internal.scene.clientDialog = None
         self.deferred.callback(answer)
 
@@ -379,11 +384,9 @@ class HumanClient(Client):
         self.ruleset = None
         self.beginQuestion = None
         self.tableList = TableList(self)
-        Connection(
-            self).login(
-        ).addCallbacks(
+        Connection(self).login().addCallbacks(
             self.__loggedIn,
-             self.__loginFailed)
+            self.__loginFailed)
 
     @staticmethod
     def shutdownHumanClients(exception=None):
@@ -435,7 +438,8 @@ class HumanClient(Client):
         maxGameId = int(maxGameId) if maxGameId else 0
         self.callServer('setClientProperties',
                         Internal.db.identifier,
-                        voiceId, maxGameId, Internal.version).addCallbacks(self.__initTableList, self.__versionError)
+                        voiceId, maxGameId,
+                        Internal.defaultPort).addCallbacks(self.__initTableList, self.__versionError)
 
     def __initTableList(self, dummy):
         """first load of the list. Process options like --demo, --table, --join"""
@@ -510,7 +514,7 @@ class HumanClient(Client):
         Client.remote_tableRemoved(self, tableid, message, *args)
         self.__updateTableList()
         if message:
-            if not self.name in args or not message.endswith('has logged out'):
+            if self.name not in args or not message.endswith('has logged out'):
                 logWarning(m18n(message, *args))
 
     def __receiveTables(self, tables):
@@ -522,7 +526,6 @@ class HumanClient(Client):
                 # previously selected ruleset
                 self.tables = list(
                     x for x in self.tables if x.ruleset == self.ruleset)
-                assert self.tables
         if len(self.tables):
             self.__updateTableList()
 
@@ -533,9 +536,7 @@ class HumanClient(Client):
         def gotRulesets(result):
             """the server sent us the wanted ruleset definitions"""
             for ruleset in result:
-                Ruleset.cached(
-                    ruleset).save(
-                )  # make it known to the cache and save in db
+                Ruleset.cached(ruleset).save()  # make it known to the cache and save in db
             return tables
         rulesetHashes = set(x[1] for x in tables)
         needRulesets = list(
@@ -594,7 +595,7 @@ class HumanClient(Client):
             table.chatWindow.receiveLine(chatLine)
 
     def readyForGameStart(
-        self, tableid, gameid, wantedGame, playerNames, shouldSave=True,
+            self, tableid, gameid, wantedGame, playerNames, shouldSave=True,
             gameClass=None):
         """playerNames are in wind order ESWN"""
         if gameClass is None:
@@ -889,8 +890,10 @@ class HumanClient(Client):
             if debugArgs[0] == 'ping':
                 return
             if debugArgs[0] == 'setClientProperties':
-                debugArgs[1] = u'DBID'
-                debugArgs[3] = u'GAMEID'
+                debugArgs[1] = 'DBID'
+                debugArgs[3] = 'GAMEID'
+                if debugArgs[4] >= 8300:
+                    debugArgs[4] -= 300
         if self.game:
             self.game.debug('callServer(%s)' % repr(debugArgs))
         else:
@@ -915,7 +918,7 @@ class HumanClient(Client):
                 logWarning(
                     m18n(
                         'The connection to the server %1 broke, please try again later.',
-                          self.connection.url))
+                        self.connection.url))
                 self.remote_serverDisconnects()
                 return succeed(None)
         else:
