@@ -21,11 +21,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 import datetime
 
 from log import m18n, m18nc, m18ncE, logWarning, logException, logDebug
-from sound import Voice, Sound
+from sound import Voice
 from tile import Tile, TileList
 from meld import Meld, MeldList
-from common import Internal, Debug, long
-from common import unicode, unicodeString, StrMixin
+from common import Internal, Debug, Options, long
+from common import unicode, unicodeString
+from wind import Wind
 from dialogs import Sorry
 
 # pylint: disable=super-init-not-called
@@ -48,7 +49,6 @@ class Message(object):
         self.shortcut = shortcut
         # do not use a numerical value because that could easier
         # change with software updates
-        Message.defined[self.name] = self
         className = self.__class__.__name__.replace('Message', '')
         msgName = self.name.replace(' ', '')
         assert className == msgName, '%s != %s' % (className, msgName)
@@ -62,6 +62,9 @@ class Message(object):
     def __repr__(self):
         return 'Message.{}'.format(self.name)
 
+    def __lt__(self, other):
+        return self.__class__.__name__ < other.__class__.__name__
+
     @staticmethod
     def jelly(key, value):
         """serialize value for wire transfer. The twisted.pb mechanism with
@@ -70,6 +73,8 @@ class Message(object):
         cls = value.__class__
         if cls in (Tile, TileList, Meld, MeldList):
             return str(value).encode()
+        elif isinstance(value, Wind):
+            return str(value).encode()
         elif isinstance(value, Message):
             return value.name
         elif isinstance(value, (list, tuple)):
@@ -210,13 +215,13 @@ class PungChowMessage(NotifyAtOnceMessage):
                     dangerousMelds)
             if len(dangerousMelds) == 1:
                 txt.append(m18n(
-                           'claiming %1 is dangerous because you will have to discard a dangerous tile',
-                           lastDiscard.name()))
+                    'claiming %1 is dangerous because you will have to discard a dangerous tile',
+                    lastDiscard.name()))
             else:
                 for meld in dangerousMelds:
                     txt.append(m18n(
-                               'claiming %1 for %2 is dangerous because you will have to discard a dangerous tile',
-                               lastDiscard.name(), str(meld)))
+                        'claiming %1 for %2 is dangerous because you will have to discard a dangerous tile',
+                        lastDiscard.name(), str(meld)))
         if not txt:
             txt = [m18n('You may say %1', self.i18nName)]
         return '<br><br>'.join(txt), warn, ''
@@ -365,7 +370,7 @@ class MessageOriginalCall(NotifyAtOnceMessage, ServerMessage):
             return (m18n(
                 'Discard a tile, declaring Original Call meaning you need only one '
                 'tile to complete the hand and will not alter the hand in any way (except bonus tiles)'),
-                False, '')
+                    False, '')
 
     def clientAction(self, client, move):
         """mirror the original call"""
@@ -411,8 +416,8 @@ class MessageDiscard(ClientMessage, ServerMessage):
             warn = True
         if not txt:
             txt = [m18n('discard the least useful tile')]
-        txt = '<br><br>'.join(txt)
-        return txt, warn, txt
+        txtStr = '<br><br>'.join(txt)
+        return txtStr, warn, txtStr
 
     def clientAction(self, client, move):
         """execute the discard locally"""
@@ -430,7 +435,7 @@ class MessageProposeGameId(ServerMessage):
 
     def clientAction(self, client, move):
         """ask the client"""
-        # move.source are the players in seating order
+        # move.playerNames are the players in seating order
         # we cannot just use table.playerNames - the seating order is now
         # different (random)
         return client.reserveGameId(move.gameid)
@@ -467,11 +472,12 @@ class MessageReadyForGameStart(ServerMessage):
                         client.name)
                 client.tableList.hide()
             return result
-        # move.source are the players in seating order
+        # move.playerNames are the players in seating order
         # we cannot just use table.playerNames - the seating order is now
         # different (random)
-        return client.readyForGameStart(move.tableid, move.gameid,
-                                        move.wantedGame, move.source, shouldSave=move.shouldSave).addCallback(hideTableList)
+        return client.readyForGameStart(
+            move.tableid, move.gameid,
+            move.wantedGame, move.playerNames, shouldSave=move.shouldSave).addCallback(hideTableList)
 
 
 class MessageNoGameStart(NotifyAtOnceMessage):
@@ -499,7 +505,7 @@ class MessageReadyForHandStart(ServerMessage):
 
     def clientAction(self, client, move):
         """ask the client"""
-        return client.readyForHandStart(move.source, move.rotateWinds)
+        return client.readyForHandStart(move.playerNames, move.rotateWinds)
 
 
 class MessageInitHand(ServerMessage):
@@ -612,7 +618,7 @@ class MessageVoiceId(ServerMessage):
 
     def clientAction(self, dummyClient, move):
         """the server gave us a voice id about another player"""
-        if Internal.Preferences.useSounds:
+        if Internal.Preferences.useSounds and Options.gui:
             move.player.voice = Voice.locate(move.source)
             if not move.player.voice:
                 return Message.ClientWantsVoiceData, move.source
@@ -635,7 +641,7 @@ class MessageAssignVoices(ServerMessage):
     """The server tells us that we now got all voice data available"""
 
     def clientAction(self, client, move):
-        if Internal.Preferences.useSounds:
+        if Internal.Preferences.useSounds and Options.gui:
             client.game.assignVoices()
 
 
@@ -700,8 +706,8 @@ class MessageRobbedTheKong(NotifyAtOnceMessage, ServerMessage):
     def clientAction(self, client, move):
         """mirror the action locally"""
         prevMove = next(client.game.lastMoves(only=[Message.DeclaredKong]))
-        prevMove.player.robTile(prevMove.meld[0].concealed)
-        move.player.lastSource = 'k'
+        prevMove.player.robTileFrom(prevMove.meld[0].concealed)
+        move.player.robsTile()
         client.game.addCsvTag(
             'robbedKong%s' % prevMove.meld[1],
             forAllPlayers=True)
@@ -841,6 +847,7 @@ def __scanSelf():
                             raise
                         type.__setattr__(
                             Message, msg.name.replace(' ', ''), msg)
+                        Message.defined[msg.name] = msg
 
 
 class ChatMessage(object):
@@ -873,6 +880,8 @@ class ChatMessage(object):
 
     def __unicode__(self):
         local = self.localtimestamp()
+        # pylint: disable=no-member
+        # pylint says something about NotImplemented, check with later versions
         return u'statusMessage=%s %02d:%02d:%02d %s: %s' % (
             unicode(self.isStatusMessage),
             local.hour,
